#' shinyWidgets: Custom inputs widgets for Shiny.
#'
#' The shinyWidgets package provides several custom widgets to extend those available in package shiny
#'
#' @examples
#' if (interactive()) {
#'   shinyWidgets::shinyWidgetsGallery()
#' }
#'
#' @name shinyWidgets
"_PACKAGE"
